@@ -1360,6 +1360,27 @@ numeric_hex = (
     0X11DA7,
     0X11DA8,
     0X11DA9,
+    0X11FC0,
+    0X11FC1,
+    0X11FC2,
+    0X11FC3,
+    0X11FC4,
+    0X11FC5,
+    0X11FC6,
+    0X11FC7,
+    0X11FC8,
+    0X11FC9,
+    0X11FCA,
+    0X11FCB,
+    0X11FCC,
+    0X11FCD,
+    0X11FCE,
+    0X11FCF,
+    0X11FD0,
+    0X11FD1,
+    0X11FD2,
+    0X11FD3,
+    0X11FD4,
     0X12400,
     0X12401,
     0X12402,
@@ -1616,6 +1637,26 @@ numeric_hex = (
     0X1D7FD,
     0X1D7FE,
     0X1D7FF,
+    0X1E140,
+    0X1E141,
+    0X1E142,
+    0X1E143,
+    0X1E144,
+    0X1E145,
+    0X1E146,
+    0X1E147,
+    0X1E148,
+    0X1E149,
+    0X1E2F0,
+    0X1E2F1,
+    0X1E2F2,
+    0X1E2F3,
+    0X1E2F4,
+    0X1E2F5,
+    0X1E2F6,
+    0X1E2F7,
+    0X1E2F8,
+    0X1E2F9,
     0X1E8C7,
     0X1E8C8,
     0X1E8C9,
@@ -1701,6 +1742,66 @@ numeric_hex = (
     0X1ECB2,
     0X1ECB3,
     0X1ECB4,
+    0X1ED01,
+    0X1ED02,
+    0X1ED03,
+    0X1ED04,
+    0X1ED05,
+    0X1ED06,
+    0X1ED07,
+    0X1ED08,
+    0X1ED09,
+    0X1ED0A,
+    0X1ED0B,
+    0X1ED0C,
+    0X1ED0D,
+    0X1ED0E,
+    0X1ED0F,
+    0X1ED10,
+    0X1ED11,
+    0X1ED12,
+    0X1ED13,
+    0X1ED14,
+    0X1ED15,
+    0X1ED16,
+    0X1ED17,
+    0X1ED18,
+    0X1ED19,
+    0X1ED1A,
+    0X1ED1B,
+    0X1ED1C,
+    0X1ED1D,
+    0X1ED1E,
+    0X1ED1F,
+    0X1ED20,
+    0X1ED21,
+    0X1ED22,
+    0X1ED23,
+    0X1ED24,
+    0X1ED25,
+    0X1ED26,
+    0X1ED27,
+    0X1ED28,
+    0X1ED29,
+    0X1ED2A,
+    0X1ED2B,
+    0X1ED2C,
+    0X1ED2D,
+    0X1ED2F,
+    0X1ED30,
+    0X1ED31,
+    0X1ED32,
+    0X1ED33,
+    0X1ED34,
+    0X1ED35,
+    0X1ED36,
+    0X1ED37,
+    0X1ED38,
+    0X1ED39,
+    0X1ED3A,
+    0X1ED3B,
+    0X1ED3C,
+    0X1ED3D,
     0X1F100,
     0X1F101,
     0X1F102,
@@ -1743,7 +1844,7 @@ if __name__ == "__main__":
             a = py23_unichr(i)
         except ValueError:
             break
-        if a in set("0123456789"):
+        if a in "0123456789":
             continue
         if unicodedata.numeric(a, None) is not None:
             hex_chars.append(i)
